
var gOCSPDialog = {
  mCertDB         : null,
  mOCSPResponders : null,
  mPrefBranch     : null,

  init: function ()
  {
    this.mCertDB = Components.classes["@mozilla.org/security/x509certdb;1"]
                             .getService(Components.interfaces.nsIX509CertDB);
    this.mOCSPResponders = this.mCertDB.getOCSPResponders();
    this.mPrefBranch = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);

    document.getElementById('securityOCSPEnabled').selectedIndex = this.mPrefBranch.getIntPref('security.OCSP.enabled');

    var selectedItemIndex = 0;
    var signingCAValue;
    try {
      signingCAValue = this.mPrefBranch.getCharPref('security.OCSP.signingCA');
    } catch (ex) {}

    var signingCA = document.getElementById("signingCA");
    var serviceURL = document.getElementById('serviceURL');
    const nsIOCSPResponder = Components.interfaces.nsIOCSPResponder;
    for (var index = 0; index < this.mOCSPResponders.length; ++index) 
    {
      var ocspEntry = this.mOCSPResponders.queryElementAt(index, nsIOCSPResponder);
      var menuitem = document.createElement("menuitem");
      menuitem.setAttribute("value", ocspEntry.responseSigner);
      menuitem.setAttribute("label", ocspEntry.responseSigner);
      signingCA.firstChild.appendChild(menuitem);
      if (ocspEntry.responseSigner == signingCAValue)
        selectedItemIndex = index;       
    }

    // now select the correct item in the list...
    signingCA.selectedIndex = selectedItemIndex;

    try 
    {
      serviceURL.value = this.mPrefBranch.getCharPref('security.OCSP.URL');
    } 
    catch (ex)
    {
      // if there is no default OCSP server URL overrride, then just choose the one for the current signingCA...
      this.chooseServiceURL();
    }
    
    this.updateUI();
  },

  onAccept: function()
  {
    this.mPrefBranch.setIntPref('security.OCSP.enabled', document.getElementById('securityOCSPEnabled').value);
    this.mPrefBranch.setCharPref('security.OCSP.signingCA', document.getElementById('signingCA').value);
    this.mPrefBranch.setCharPref('security.OCSP.URL', document.getElementById('serviceURL').value);
  },
  
  updateUI: function ()
  {
    var signingCA = document.getElementById("signingCA");
    var serviceURL = document.getElementById("serviceURL");
    var securityOCSPEnabled = document.getElementById("securityOCSPEnabled");

    var OCSPEnabled = parseInt(securityOCSPEnabled.value);
    signingCA.disabled = serviceURL.disabled = OCSPEnabled == 0 || OCSPEnabled == 1;
  },
  
  chooseServiceURL: function ()
  {
    var signingCA = document.getElementById("signingCA");
    var serviceURL = document.getElementById("serviceURL");
    var CA = signingCA.value;
    
    const nsIOCSPResponder = Components.interfaces.nsIOCSPResponder;
    for (var i = 0; i < this.mOCSPResponders.length; ++i) 
    {
      var ocspEntry = this.mOCSPResponders.queryElementAt(i, nsIOCSPResponder);
      if (CA == ocspEntry.responseSigner) 
      {
        serviceURL.value = ocspEntry.serviceURL;
        break;
      }
    }
  },
};
